@@ -4,3 +4,7 @@ def tok_begin(tokenizer):
 
 def tok_sep(tokenizer):
     return tokenizer._sep_token or tokenizer._eos_token or 'sep'
+
+
+def tok_mask(tokenizer):
+    return tokenizer._mask_token or 'msk'
